import './routes/index.ts';
import { app } from './app.ts';
import { useConfig } from '@kevisual/use-config';
import { User } from './models/user.ts';
import { createAuthRoute } from '@kevisual/auth';
const config = useConfig<{ tokenSecret: string }>();

createAuthRoute({
  app,
  secret: config.tokenSecret,
});

app
  .route({
    path: 'auth',
    key: 'admin',
    id: 'auth-admin',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const tokenUser = ctx.state.tokenUser;
    const user = await User.findOne({
      where: {
        id: tokenUser.id,
      },
    });
    if (!user) {
      ctx.throw(404, 'user not found');
    }
    const orgs = await user.getOrgs();

    if (orgs.includes('admin')) {
      ctx.body = 'admin';
    } else {
      ctx.throw(403, 'forbidden');
    }
  })
  .addTo(app);

app
  .route({
    path: 'test',
    key: 'test',
  })
  .define(async (ctx) => {
    ctx.body = app.router.routes.map((item) => {
      return {
        path: item.path,
        key: item.key,
        description: item.description,
        validator: item.validator,
        // schema: item.schema,
      };
    });
  })
  .addTo(app);
